@@ -79,6 +79,9 @@ def test_jsend():
     assert rr.status == 'error'
     assert rr.message is not None
 
+    # check code initial
+    assert rs.code == 0 and rf.code == 0
+
     for i in lst:
         i.data['hello'] = 'hello'
         assert i.data['hello'] == 'hello'
@@ -113,6 +116,16 @@ def test_jsend():
     except Exception as e:
         print(e)
         assert False
+
+
+    # test code part
+    for i in lst:
+        try:
+            i.code = 200
+        except Exception as e:
+            assert False
+
+
     #     try:
     #         i.data = 'abc'
     #     except AttributeError as e:
